# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_sund.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/03_sund.ipynb 5
_MEMBER_NAMES_ = '_member_names_'

# %% ../nbs/03_sund.ipynb 6
_REPR_HTML_ = '_repr_html_'
_REPR_LATEX_ = '_repr_latex_'
_REPR_DATA_RESOURCE_ = '_repr_data_resource_'
