# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/06_errs.ipynb.

# %% auto 0
__all__ = ['RET', 'ERR', 'ERRS', 'NONE', 'ERRORS', 'RETNONE', 'RETERRS', 'RETERRORS']

# %% ../nbs/06_errs.ipynb 5
RET = 'ret'
ERR = 'err'
ERRS = f'{ERR}s'
NONE = 'none'
ERRORS = f'{ERR}ors'
RETNONE = f'{RET}none'
RETERRS = f'{RET}{ERRS}'
RETERRORS = f'{RET}{ERRORS}'
