# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/57_pkgs.ipynb.

# %% auto 0
__all__ = ['NAME', 'NOTE', 'LEVEL', 'ARM', 'NO_ARM_SUPPORT', 'CFG', 'CONFIG', 'CONFIGS', 'ALWAYS', 'CHECKED', 'ENV', 'LIT', 'PIP',
           'PYPI', 'CONDA', 'PYTHON', 'DEP', 'DEPS', 'DEPENDENCIES', 'SUBCATS', 'SUBCATEGORIES', 'CHANNEL', 'CHANNELS',
           'ONLY', 'PIP_ONLY', 'CUDA_ONLY', 'PYPI_NAME']

# %% ../nbs/57_pkgs.ipynb 4
from .args import TYPE
from .exps import SUB, CATS, CATEGORIES

# %% ../nbs/57_pkgs.ipynb 5
NAME = 'name'
NOTE = 'note'

LEVEL = 'level'

ARM = 'arm'
NO_ARM_SUPPORT = f'no_{ARM}_support'

# %% ../nbs/57_pkgs.ipynb 6
CFG = 'cfg'
CONFIG = 'config'
CONFIGS = f'{CONFIG}s'

# %% ../nbs/57_pkgs.ipynb 7
ALWAYS = 'always'
CHECKED = 'checked'

# %% ../nbs/57_pkgs.ipynb 8
ENV = 'env'
LIT = 'lit'

# %% ../nbs/57_pkgs.ipynb 9
PIP = 'pip'
PYPI = 'pypi'
CONDA = 'conda'
PYTHON = 'python'

# %% ../nbs/57_pkgs.ipynb 10
DEP = 'dep'
DEPS = f'{DEP}s'
DEPENDENCIES = f'{DEP}endencies'

# %% ../nbs/57_pkgs.ipynb 11
SUBCATS = f'{SUB}{CATS}'
SUBCATEGORIES = f'{SUB}{CATEGORIES}'

# %% ../nbs/57_pkgs.ipynb 12
CHANNEL = 'channel'
CHANNELS = f'{CHANNEL}s'

# %% ../nbs/57_pkgs.ipynb 13
ONLY = 'only'
PIP_ONLY = f'{PIP}_{ONLY}'
CUDA_ONLY = f'cuda_{ONLY}'

# %% ../nbs/57_pkgs.ipynb 14
PYPI_NAME = f'{PYPI}_{NAME}'
