# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/53_mods.ipynb.

# %% auto 0
__all__ = ['OS', 'SYS', 'TF', 'TORCH', 'TQDM', 'RICH', 'TYPER', 'SCANPY', 'SCPREP', 'ANNDATA', 'PHATE', 'MAGIC', 'NUMPY',
           'PANDAS', 'SCIPY', 'SEABORN', 'MATPLOTLIB', 'IPYTHON', 'BEARTYPE']

# %% ../nbs/53_mods.ipynb 5
OS = 'os'
SYS = 'sys'
TF = 'tf'
TORCH = 'torch'

TQDM = 'tqdm'
RICH = 'rich'
TYPER = 'typer'

SCANPY = 'scanpy'
SCPREP = 'scprep'
ANNDATA = 'anndata'

PHATE = 'phate'
MAGIC = 'magic'

NUMPY = 'numpy'
PANDAS = 'pandas'
SCIPY = 'scipy'

SEABORN = 'seaborn'
MATPLOTLIB = 'matplotlib'

IPYTHON = 'ipython'
BEARTYPE = 'beartype'
