# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/56_vers.ipynb.

# %% auto 0
__all__ = ['VER', 'PRE', 'POST', 'EPOCH', 'MAJOR', 'MINOR', 'MICRO', 'PUBLIC', 'SERIAL', 'RELEASE', 'VERSION', 'VERSION_INFO',
           'BASE_VERSION', 'RELEASELEVEL']

# %% ../nbs/56_vers.ipynb 4
from .args import TYPE

# %% ../nbs/56_vers.ipynb 5
VER = 'ver'

PRE = 'pre'
POST = 'post'
EPOCH = 'epoch'
MAJOR = 'major'
MINOR = 'minor'
MICRO = 'micro'

PUBLIC = 'public'
SERIAL = 'serial'

RELEASE = 'release'
VERSION = f'{VER}sion'

VERSION_INFO = f'{VERSION}_info'
BASE_VERSION = f'base_{VERSION}'

RELEASELEVEL = f'{RELEASE}level'
